@@ -1,5 +1,5 @@
 package App::pherkin;
-$App::pherkin::VERSION = '0.44';
+$App::pherkin::VERSION = '0.47';
 use strict;
 use warnings;
 
@@ -31,7 +31,7 @@ App::pherkin - Run Cucumber tests from the command line
 
 =head1 VERSION
 
-version 0.44
+version 0.47
 
 =head1 SYNOPSIS
 
@@ -94,7 +94,9 @@ sub _run_tests {
             { tags => $self->tag_scheme } );
     }
 
+    $_->pre_execute() for @{ $self->extensions };
     $executor->execute( $_, $harness, $tag_spec ) for @features;
+    $_->post_execute() for reverse @{ $self->extensions };
 
     $harness->shutdown();
     return $harness->result;
@@ -167,7 +169,7 @@ sub _load_config {
         }
     }
 
-    $profile_name //= 'default';
+    $profile_name = 'default' unless defined $profile_name;
 
     # Check the config file has the right type of data at the profile name
     unless ( ref $config_data_whole eq 'HASH' ) {
@@ -239,7 +241,7 @@ sub _process_arguments {
     GetOptions(
         map {
             my $x;
-            $_->[1] //= \$x;
+            $_->[1] = \$x unless defined $_->[1];
             ( $_->[0] => $_->[1] );
         } values %options
     );
@@ -262,9 +264,9 @@ sub _process_arguments {
     # Merge those configuration items
     # First we need a list of matching keys
     my %keys = map {
-        my ( $key_basis, $ref ) = @$_;
-        map { $_ => $ref } map { s/=.+//; $_ } split( /\|/, $key_basis );
-    } values %options;
+        my ( $key_basis, $ref ) = @{$options{$_}};
+        map { $_ => $ref } map { s/=.+//; $_ } (split( /\|/, $key_basis ), $_);
+    } keys %options;
 
     # Now let's go through each option. For arrays, we want the configuration
     # options to appear in order at the front. So if configuration had 1, 2,
@@ -310,7 +312,7 @@ sub _process_arguments {
             if ( ref $value ) {
                 print join ', ', @$value;
             } else {
-                print $value // '[undefined]';
+                print ((defined $value) ? $value : '[undefined]' );
             }
             print "\n";
         }
@@ -441,7 +443,7 @@ Peter Sergeant C<pete@clueball.com>
 
 =head1 LICENSE
 
-Copyright 2011-2014, Peter Sergeant; Licensed under the same terms as Perl
+Copyright 2011-2016, Peter Sergeant; Licensed under the same terms as Perl
 
 =cut
 
