@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Extension;
-$Test::BDD::Cucumber::Extension::VERSION = '0.45';
+$Test::BDD::Cucumber::Extension::VERSION = '0.47';
 =head1 NAME
 
 Test::BDD::Cucumber::Extension - Abstract superclass for extensions
 
 =head1 VERSION
 
-version 0.45
+version 0.47
 
 =head1 DESCRIPTION
 
@@ -43,6 +43,22 @@ the extension is loaded.
 
 sub step_directories { return []; }
 
+=head2 pre_execute()
+
+Invoked by App::pherkin before executing any features.  This callback
+allows generic extension setup. Reports errors by calling croak().
+
+=head2 post_execute()
+
+Invoked by App::pherkin after executing all features.  This callback
+allows generic extension teardown and cleanup. Reports errors by calling
+croak().
+
+=cut
+
+sub pre_execute  { return; }
+sub post_execute { return; }
+
 =head2 pre_feature($feature, $feature_stash)
 
 Invoked by the Executor before executing the background and feature scenarios
@@ -51,7 +67,7 @@ and their respective pre-hooks. Reports errors by calling croak().
 =head2 post_feature($feature, $feature_stash)
 
 Invoked by the Executor after executing the background and feature scenarios
-and their repective post-hooks. Reports errors by calling croak().
+and their respective post-hooks. Reports errors by calling croak().
 
 =cut
 
@@ -66,7 +82,7 @@ their respective pre-hooks. Reports errors by calling croak().
 =head2 post_scenario($scenario, $feature_stash, $scenario_stash, $failed)
 
 Invoked by the Executor after executing all the steps in $scenario
-and their repective post-hooks. Reports errors by calling croak().
+and their respective post-hooks. Reports errors by calling croak().
 
 $failure indicates whether any of the steps in the scenario has failed.
 
