@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Parser;
-$Test::BDD::Cucumber::Parser::VERSION = '0.44';
+$Test::BDD::Cucumber::Parser::VERSION = '0.47';
 =head1 NAME
 
 Test::BDD::Cucumber::Parser - Parse Feature files
 
 =head1 VERSION
 
-version 0.44
+version 0.47
 
 =head1 DESCRIPTION
 
@@ -359,10 +359,15 @@ sub _extract_table {
 
 sub _pipe_array {
     my ( $self, $string ) = @_;
-    my @atoms = split( /\|/, $string );
+    my @atoms = split( /(?<!\\)\|/, $string );
     shift(@atoms);
-    return
-      map { my $atom = $_; $atom =~ s/^\s+//; $atom =~ s/\s+$//; $atom } @atoms;
+    return map {
+        my $atom = $_;
+        $atom =~ s/^\s+//;
+        $atom =~ s/\s+$//;
+        $atom =~ s/\\(.)/$1/g;
+        $atom
+    } @atoms;
 }
 
 1;
@@ -373,6 +378,6 @@ Peter Sergeant C<pete@clueball.com>
 
 =head1 LICENSE
 
-Copyright 2011-2014, Peter Sergeant; Licensed under the same terms as Perl
+Copyright 2011-2016, Peter Sergeant; Licensed under the same terms as Perl
 
 =cut
